.. Pidgin documentation master file

Welcome to Pidgin's Documentation
==================================

Pidgin is an AI conversation research tool for studying emergent communication patterns
between language models.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   README
   installation
   quickstart

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   cli-usage
   yaml-specs
   custom-awareness
   
.. toctree::
   :maxdepth: 2
   :caption: API Documentation

   api/index
   api/core
   api/providers
   api/metrics
   api/experiments
   api/analysis

.. toctree::
   :maxdepth: 2
   :caption: Architecture

   ARCHITECTURE
   database
   metrics
   conversation-architecture

.. toctree::
   :maxdepth: 2
   :caption: Reference

   api_reference
   changelog
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`